import requests
import urllib3

urllib3.disable_warnings()

def check(thai_id, thai_name, thai_surname, thai_year=2562):

    URL = 'https://refundedcheque.rd.go.th/itp_x_tw/pages/n/result.jsp'
    URL_API = 'https://refundedcheque.rd.go.th/itp_x_tw/SearchTaxpayerServlet'

    headers = {
        'Referer': 'https://refundedcheque.rd.go.th/itp_x_tw/pages/n/inquire.jsp'
    }

    s = requests.Session()
    r = s.get(URL, headers=headers, verify=False)

    data = {
        'taxYear': thai_year,
        'fName': thai_name,
        'lName': thai_surname,
        'nid': thai_id,
        'searchType': None,
        'effDate': None,
    }

    headers = {
        'Referer': URL
    }

    r = s.post(URL_API, data=data, headers=headers, verify=False)

    if r.status_code != 200:
        return None

    raw_data = r.json()

    process_dict = {
        'process_1': 'ยื่นแบบฯ',
        'process_2': 'ดำเนินการ',
        'process_3': 'พิจารณาคืนภาษี',
        'process_4': 'ส่งคืนภาษี',
        'process_5': 'ได้คืนภาษี',
    }

    raw_data['process_text'] = process_dict.get(raw_data['processPicName'], '')
    
    return raw_data


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name='thaitaxrefund',
    version='0.2',
    author="Kittinan Srithaworn",
    description="Thai tax refund checker",
    long_description=long_description,
    long_description_content_type="text/markdown",
    license='MIT',
    install_requires=['requests'],
    keywords='thai tax refund',
    url="https://github.com/kittinan/thai-tax-refund",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        'License :: OSI Approved :: MIT License',
        "Operating System :: OS Independent",
    ],

    project_urls={
        'Bug Reports': 'https://github.com/kittinan/thai-tax-refund/issues',
        'Source': 'https://github.com/kittinan/thai-tax-refund',
    },
)
